@@ -8,8 +8,8 @@ main program executable
 import sys
 
 # additional libraries
-from . import merakitoolkitparser # pylint: disable=import-error
-from . import merakitoolkit
+import merakitoolkit.merakitoolkitparser as merakitoolkitparser # pylint: disable=import-error
+import merakitoolkit.merakitoolkit as merakitoolkit
 
 def main() -> int:
     '''merakitoolkit main program call'''
